/*:ts=8*/
/*****************************************************************************
 * FIDOGATE --- Gateway software UNIX <-> FIDO
 *
 * $Id: config.h,v 3.1 1993/09/14 07:40:04 mj beta mj $
 *
 * Configuration header file
 *
 *****************************************************************************
 * Copyright (C) 1990, 1993
 *  _____ _____
 * |     |___  |   Martin Junius             FIDO:      2:242/6.1
 * | | | |   | |   Republikplatz 3           Internet:  mj@sungate.fido.de
 * |_|_|_|@home|   D-52072 Aachen, Germany   Phone:     ++49-241-86931 (voice)
 *
 * This file is part of FIDOGATE.
 *
 * FIDOGATE is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 *
 * FIDOGATE is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with FIDOGATE; see the file COPYING.  If not, write to the Free
 * Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 *****************************************************************************/

/*
 * This is our net and node number
 *
 * We're 2:242/6.1 with fake address 2:6000/1
 */
#define REAL_ZONE	2
#define REAL_NET	242
#define REAL_NODE	6
#define REAL_POINT	1

#define MY_ZONE		2
#define MY_NET		6000
#define MY_NODE		1
#define MY_POINT	0


/*
 * Packet type 2+ (4D), else 2 (StoneAge)
 *
 * If this is enabled and the fakenet address is a 4D point address (same
 * as REAL_*), then 4D addressing will be used for EchoMail. Currently
 * FIDOGATE generates SEEN-BY and ^APATH like this:
 *     SEEN-BY: 242/6.1
 *     ^APATH: 242/6.1
 * There seems to be no standard for 4D EchoMail addressing. If you run
 * into problems with this kind of EchoMail message, please change the
 * code in rfc2fido.c:print_origin().
 */
#define PACKET_2PLUS

/*
 * Packet password (exactly 8 characters, pad with \0)
 */
#define PACKET_PASSWD	"\0\0\0\0\0\0\0\0"

/*
 * Product code for packets generated by FIDOGATE, 0xfe is used because
 * this code is reserved for new products, when the code numbers ran out.
 */
#define PRODUCT_CODE	0xfe

/*
 * Origin line for FIDO EchoMail
 */
#define ORIGIN		"Fido.DE domain administration at sungate.fido.de"

/*
 * This is where our mail goes to ...
 */
#define REM_ZONE	2
#define REM_NET		242
#define REM_NODE	6
#define REM_POINT	0
 
/*
 * Domain suffix (added to hostname)
 */
#define MY_HOSTNAME	"sungate"
#define MY_DOMAIN	".fido.de"

/*
 * Domain suffix for standard FIDO addresses
 * DO NOT CHANGE THIS!
 */
#define FIDODOMAIN	".fidonet.org"

/*
 * Extra domains to be recognized as FIDO addresses
 */
#define EXTRA_DOMAIN_1	".fido.sub.org"
/* #define EXTRA_DOMAIN_2	".koelnnet" */


/*
 * Generate local From addresses, user%p.f.n.z@HOSTNAME.DOMAIN
 */
/* #define LOCAL_FROM */

/*
 * Return address for bounced mail. An `Errors-To:' header will
 * be inserted for mail addressed via `To:' from FIDO if defined.
 */
/* #define ERRORS_TO	    "root@hippo.dfv.rwth-aachen.de" */

/*
 * Add `@host.domain' to local addresses
 */
#define ADD_DOMAIN

/*
 * Postmaster name
 */
#define POSTMASTER	"postmaster"


/*
 * Enable conversion of the addresses generated by the MAUS <-> FIDO
 * gateway to their Internet form, e.g.
 *     `User Name % MAUS AC'  -->  `user_name@ac.maus.de'
 * and vice versa.
 */
#define MAUS_DE
#define MAUS_DOMAIN	".maus.de"
#define MAUS_STRING	"_%_MAUS_"	/* For addressing gateway */
#define MAUS_ZONE	2		/* Address of the gateway */
#define MAUS_NET	242
#define MAUS_NODE	42
#define MAUS_POINT	6


/*
 * Enable special handling for FIDO nodes registered to domain .fido.de
 */
#define FIDO_DE
#define FIDO_DE_DOMAIN	".fido.de"	/* Domain name */
#define FIDO_DE_RESTRICTED		/* Restrict mail to registered nodes */
#define FIDO_DE_POSTMASTER "Martin Junius @ FIDO 2:242/6.1"


/*
 * Send all Internet mail via FIDO and a FIDO<->Internet gateway.
 * This allows to use FIDOGATE in a FIDO point setup. Uncomment the first
 * define to enable this feature and set the gateway address accordingly.
 */
/* #define FIDO_GATE */
#define FIDO_GATE_NAME	"UUCP"		/* User name of gateway address */
#define FIDO_GATE_ZONE	2		/* Gateway FIDO address */
#define FIDO_GATE_NET	242
#define FIDO_GATE_NODE	6
#define FIDO_GATE_POINT	1


/*
 * Files in LIBDIR
 */
#define HOSTS		"hosts"		/* Host file (Fido.DE) */
#define ALIASES		"aliases"	/* User aliases file */
#define AREAS		"areas"		/* Areas <-> Newsgroups */
#define DOMAINS		"domains"	/* Zones -> Internet domain names */

#define LOG		"log"		/* Log file */

#define SEQ_MAIL	"seq.mail"	/* fido2rfc: mail files */
#define SEQ_NEWS	"seq.news"	/* fido2rfc: news files */
#define SEQ_MSGID	"seq.msgid"	/* rfc2fido: ^AMSGID */
#define SEQ_PKT		"seq.pkt"	/* rfc2fido: outgoing packets */

/*
 * Directories in SPOOLDIR
 */
#define INBOUND		"in"		/* Input for fido2rfc */
#define INBOUND_MAIL	"mail"		/* in/mail output from fido2rfc */
#define INBOUND_NEWS	"news"		/* in/news Output from fido2rfc */
#define INBOUND_BAD	"in/bad"	/* fidorun: bad stuff */
#define UNSECURE	"unsecure"	/* Unsecure input for fido2rfc */
#define OUTBOUND	"out"		/* Output of rfc2fido */

#define PACKET_MODE	0666		/* Mode for outbound packets */

/*
 * Uncomment the following define if you want FLO files for BinkleyTerm
 * in the outbound directory.
 */
/* #define BINKLEY_FLO	".DLO" */



/***** DO NOT CHANGE ANYTHING BELOW THIS LINE ********************************/

/*
 * Open modes for fopen()
 */
#define R_MODE		"r"
#define W_MODE		"w"
#define A_MODE		"a"
#define RP_MODE		"r+"
#define WP_MODE		"w+"
#define AP_MODE		"a+"



/*
 * System dependend configuration
 */

/***** File locking *****/
#ifdef BSD
# undef  LOCK_LOCKF			/* BSD uses flock() */
#endif
#ifdef USG
# define LOCK_LOCKF			/* System V uses lockf() */
#endif

#ifdef __linux__			/* LINUX only got flock() */
# undef  LOCK_LOCKF
#endif
#ifdef sun
# define LOCK_LOCKF			/* SUNOS 4.1.x got lockf(), too. */
#endif


/*
 * Width of formatted messages. Lines will be wrapped to be less
 * than this. If word is longer than 2/3s of MAX_LINELEN, it will be
 * cut instead of correct wrapping.
 */
#define MAX_LINELEN 80
