/*:ts=8*/
/*****************************************************************************
 * FIDOGATE --- Gateway software UNIX <-> FIDO
 *
 * $Id: fidogate.h,v 3.1 1993/09/14 07:40:04 mj beta mj $
 *
 * Common header file
 *
 *****************************************************************************
 * Copyright (C) 1990, 1993
 *  _____ _____
 * |     |___  |   Martin Junius             FIDO:      2:242/6.1
 * | | | |   | |   Republikplatz 3           Internet:  mj@sungate.fido.de
 * |_|_|_|@home|   D-52072 Aachen, Germany   Phone:     ++49-241-86931 (voice)
 *
 * This file is part of FIDOGATE.
 *
 * FIDOGATE is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 *
 * FIDOGATE is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with FIDOGATE; see the file COPYING.  If not, write to the Free
 * Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 *****************************************************************************/

#include "config.h"

#include "paths.h"		    /* Automatically generated by Makefile */


/*
 * default level of debug output
 */
#ifndef INIT_VERBOSE
# ifdef DEBUG
#  define INIT_VERBOSE 3 /*20*/
# else
#  define INIT_VERBOSE 0
# endif
#endif


/*
 * heavy includin' ...
 */

/***** System *****/
#include <stdio.h>
#ifdef __STDC__
#include <stdlib.h>
#include <stdarg.h>
#else
#include <varargs.h>
#endif
#include <ctype.h>
#include <string.h>
#include <sys/types.h>
#include <time.h>
#include <errno.h>
#ifdef M_XENIX
# include <sys/ndir.h>
# define dirent direct
#else
# include <dirent.h>
#endif

/***** Local *****/
#include "packet.h"			/* FIDO mail packet definition */
#include "node.h"			/* nodelist definitions */
#include "sysexits.h"			/* EX_* defines */



/*
 * External functions and variables
 */

/***** System *****/
extern char *mktemp(), *getenv();
extern long time();
extern unsigned short getuid();
extern unsigned short geteuid();
extern unsigned short getgid();
extern unsigned short getegid();

/***** errno *****/
extern int errno;



/*
 * Defines
 */
#define TRUE	1
#define FALSE	0
#define BUFLEN 256
#define OK	0
#define ERROR	(-1)

#define bool	int


/*
 * We supply our own version of the toupper()/tolower()
 * macros, because the exact behaviour of those in
 * <ctype.h> varies among systems.
 */

#undef _toupper
#undef _tolower
#undef toupper
#undef tolower

#define _toupper(c) ((c)-'a'+'A')
#define _tolower(c) ((c)-'A'+'a')
#define toupper(c)  (islower(c) ? _toupper(c) : (c))
#define tolower(c)  (isupper(c) ? _tolower(c) : (c))



/* Global variable */
extern bool verbose;


/*
 * Function declarations
 */
#ifdef __STDC__
# define P(x)	x
#else
# define P(x)	()
#endif

/*
 * Function declarations for systems like SUNOS, where the standard
 * header files don't have them.
 */
#include "declare.h"


/* msgid.c */
char   *msgid_fido_to_rfc	P((char *));
char   *msgid_default		P((Node *, char *, char *, char *, time_t));
char   *msgid_rfc_to_fido	P((int *, char *, int, int));
char   *msgid_rfc_to_origid	P((char *, int, int));
char   *msgid_convert_origid	P((char *, int));

/* address.c */
extern char *address_error;

void	init_domain		P((void));
char   *get_domain		P((int));
int	check_domain		P((int));
int	parse_address		P((char *, char *, Node *));
int	isfido			P((void));
int	pfnz_to_node	        P((char *, Node *, int));
int	asc_to_node	        P((char *, Node *, int));
char   *node_to_asc	        P((Node *, int));
char   *node_to_pfnz	        P((Node *, int));
char   *node_to_domain          P((Node *));
int	parseinternode		P((char *, Node *));

/* misc.c */
void	set_libdir		P((char *));
void	stripbad	    P((char *));
char   *strncpy0	    P((char *, char *, int));
int	strnicmp	    P((char *, char *, int));
int	stricmp		    P((char *, char *));
long	xtol		    P((char *));
int	lock		    P((int));
int	unlock		    P((int));
char   *date		    P((char *, time_t *));
char   *strerror	    P((int));
void	log		    P((const char *, ...));
void	debug		    P((int, const char *, ...));
long	sequencer	    P((char *));
FILE   *spoolfile	    P((void));
FILE   *libfopen	    P((char *, char *));
FILE   *spoolfopen	    P((char *, char *));
char   *getcl		    P((char *, int, FILE *));

/* getdate.y */
extern time_t getdate();

/* bufstring.c */
char   *buf_sprintf	    P((char *, ...));

/* xalloc.c */
#define BUFFERSIZE		(16*1204)	/* Global buffer */
extern char buffer[];

char   *xmalloc			P((int));
char   *xrealloc		P((char *, int));
char   *strsave			P((char *));
char   *strsaveline		P((char *));

/* crc32.c */
unsigned long compute_crc32 P((unsigned char *, int));
void	crc32_init	    P((void));
void	crc32_compute	    P((unsigned char *, int));
unsigned long crc32_value   P((void));

/* hostalias.c */
char   *get_fido_de_host    P((Node *, int));
int	get_fido_de_node    P((char *, Node *));

/* textlist.c */
struct st_textline {
    char		*line;
    struct st_textline	*next;
};

typedef struct st_textline Textline;

struct st_textlist {
    Textline		*first;
    Textline		*last;
    unsigned long        n;
};

typedef struct st_textlist Textlist;

void	Textlist_init	    P((Textlist *));
void	Textlist_append	    P((Textlist *, char *));
void	Textlist_appendf    P((Textlist *, char *, ...));
void	Textlist_print	    P((Textlist *, FILE *));
void	Textlist_clear      P((Textlist *));
long	Textlist_size	    P((Textlist *));

/* charset.c */
void	charset_reset	    P((void));
void	charset_set	    P((char *));
char   *charset_xlate	    P((int));

/* rfc2fido.c */
/*...*/
void sendback		    P((const char *, ...));
int send_mail		    P((char *, int));
int send_message	    P((Node, char **, char *, int));
int print_msgid		    P((FILE *, char *, char *, char *, int, int));
int print_tear_line         P((FILE *));
int print_origin            P((FILE *));
int print_local_msgid       P((FILE *));

/* fido2rfc.c */
int read_int                P((FILE *));

/* rfcheader.c */
void header_delete	    P((void));
void header_read	    P((FILE *));
char *header_get	    P((char *));
char *header_getnext	    P((void));
char *name_from_rfcaddr	    P((char *, char *));
char *addr_from_rfcaddr	    P((char *, char *));
char *username_from_rfcaddr P((char *, char *));
char *addr_token	    P((char *));

/* useralias.c */
#define MAXUSERNAME 80
#define MAXFULLNAME MAX_NAME			/* Max. length FIDO name */

struct st_alias 
{
    Node node;
    char username[MAXUSERNAME];
    char fullname[MAXFULLNAME];
};

typedef struct st_alias Alias;

Alias *alias_by_username    P((char *, Node *));
Alias *alias_by_fullname    P((char *, Node *));

/* version.c */
char   *version_global		P((void));
char   *version_local		P((char *));
int	version_major		P((void));
int	version_minor		P((void));

/* read.c */
char *read_line		    P((char *, int, FILE *));
long  read_rnews_size	    P((FILE *));

/* config.c */
struct st_config 
{
    Node myaddr;		/* 4D Address */
    Node myfakeaddr;		/* 3D Fake address (or == myaddr) */
    Node remoteaddr;		/* Address for sending mail to */
};

extern struct st_config Config;

void config_init		P((void));
void config_myaddr		P((char *));
void config_myfakeaddr		P((char *));
void config_remoteaddr		P((char *));

/* wildmat */
int wildmat                     P((char *, char *));

/* getdate.y */
time_t get_date			P((char *, void *));
